==> activity-center-api-0.10.22sjq-20191217.115853-4-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceStyleUpdateDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleUpdateDto implements Serializable {

    private Long id;

    /** 广告位类型ID **/
    private Long adTypeId;

    /** 样式名称 **/
    private String adStyleName;

    /** 样式标识符 **/
    private Integer styleCode;

    /** 最少标题字数 **/
    private Integer titleMinNum;

    /** 最多标题字数 **/
    private Integer titleMaxNum;

    /** 最少描述字数 **/
    private Integer descriptionMinNum;

    /** 最多描述字数 **/
    private Integer descriptionMaxNum;

    /** ADX样式ID **/
    private String templateId;

    /** 素材数量 **/
    private Integer num;

    private List<AdvertisingSpaceStyleMaterialUpdateDto> list;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdTypeId() {
        return adTypeId;
    }

    public void setAdTypeId(Long adTypeId) {
        this.adTypeId = adTypeId;
    }

    public String getAdStyleName() {
        return adStyleName;
    }

    public void setAdStyleName(String adStyleName) {
        this.adStyleName = adStyleName;
    }

    public Integer getStyleCode() {
        return styleCode;
    }

    public void setStyleCode(Integer styleCode) {
        this.styleCode = styleCode;
    }

    public Integer getTitleMinNum() {
        return titleMinNum;
    }

    public void setTitleMinNum(Integer titleMinNum) {
        this.titleMinNum = titleMinNum;
    }

    public Integer getTitleMaxNum() {
        return titleMaxNum;
    }

    public void setTitleMaxNum(Integer titleMaxNum) {
        this.titleMaxNum = titleMaxNum;
    }

    public Integer getDescriptionMinNum() {
        return descriptionMinNum;
    }

    public void setDescriptionMinNum(Integer descriptionMinNum) {
        this.descriptionMinNum = descriptionMinNum;
    }

    public Integer getDescriptionMaxNum() {
        return descriptionMaxNum;
    }

    public void setDescriptionMaxNum(Integer descriptionMaxNum) {
        this.descriptionMaxNum = descriptionMaxNum;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public List<AdvertisingSpaceStyleMaterialUpdateDto> getList() {
        return list;
    }

    public void setList(List<AdvertisingSpaceStyleMaterialUpdateDto> list) {
        this.list = list;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> activity-center-api-0.10.46sjq-20191212.082214-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceStyleUpdateDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleUpdateDto implements Serializable {

    private Long id;

    /** 广告位类型ID **/
    private Long adTypeId;

    /** 样式名称 **/
    private String adStyleName;

    /** 广告位样式类型：1.图片 2.视频 **/
    private Integer styleType;

    /** 最少标题字数 **/
    private Integer titleMinNum;

    /** 最多标题字数 **/
    private Integer titleMaxNum;

    /** 最少描述字数 **/
    private Integer descriptionMinNum;

    /** 最多描述字数 **/
    private Integer descriptionMaxNum;

    /** ADX样式ID **/
    private String templateId;

    /** 素材数量 **/
    private Integer num;

    private List<AdvertisingSpaceStyleMaterialUpdateDto> list;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdTypeId() {
        return adTypeId;
    }

    public void setAdTypeId(Long adTypeId) {
        this.adTypeId = adTypeId;
    }

    public String getAdStyleName() {
        return adStyleName;
    }

    public void setAdStyleName(String adStyleName) {
        this.adStyleName = adStyleName;
    }

    public Integer getStyleType() {
        return styleType;
    }

    public void setStyleType(Integer styleType) {
        this.styleType = styleType;
    }

    public Integer getTitleMinNum() {
        return titleMinNum;
    }

    public void setTitleMinNum(Integer titleMinNum) {
        this.titleMinNum = titleMinNum;
    }

    public Integer getTitleMaxNum() {
        return titleMaxNum;
    }

    public void setTitleMaxNum(Integer titleMaxNum) {
        this.titleMaxNum = titleMaxNum;
    }

    public Integer getDescriptionMinNum() {
        return descriptionMinNum;
    }

    public void setDescriptionMinNum(Integer descriptionMinNum) {
        this.descriptionMinNum = descriptionMinNum;
    }

    public Integer getDescriptionMaxNum() {
        return descriptionMaxNum;
    }

    public void setDescriptionMaxNum(Integer descriptionMaxNum) {
        this.descriptionMaxNum = descriptionMaxNum;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public List<AdvertisingSpaceStyleMaterialUpdateDto> getList() {
        return list;
    }

    public void setList(List<AdvertisingSpaceStyleMaterialUpdateDto> list) {
        this.list = list;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
